/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - iconloader.cc
 *
 *  Copyright (C) 2007 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "iconloader.h"

#include <gtkmm/icontheme.h>

namespace USBSink
{

namespace UI
{

IconLoadingException::IconLoadingException(const Glib::ustring& msg)
  :
  Exception(msg)
{
}

/** \brief Loads the program icon into a Gdk::Pixbuf.
 *
 * @param size The size of icon; see constants defined in the header.
 * @returns A locked and loaded Gdk::Pixbuf.
 * @throws IconLoadingException
 */
Glib::RefPtr<Gdk::Pixbuf>
IconLoader::load_program_icon(int size)
{
  static const Glib::ustring icon_name = "usbsink";
  Glib::RefPtr<Gtk::IconTheme> theme = Gtk::IconTheme::get_default();

  if (! theme->has_icon(icon_name))
  {
    throw IconLoadingException("USBSink icon doesn't seem to be installed "
                               "in default icon theme.");
  }

  Glib::RefPtr<Gdk::Pixbuf> icon;

  try
  {
    icon = theme->load_icon(icon_name, size, Gtk::ICON_LOOKUP_USE_BUILTIN);
  }
  catch (const Glib::Error& ex)
  {
    Glib::ustring message(
      "Couldn't load program icon from the default icon theme. " +
      ex.what());

    throw IconLoadingException(message);
  }

  return icon;
}

} // namespace UI

} // namespace USBSink
