/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - transferstats.h
 *
 *  Copyright (C) 2007 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _TRANSFER_STATS_H_
#define _TRANSFER_STATS_H_

namespace USBSink
{

namespace Transfer
{

class Statistics
{
public:

  explicit Statistics();
  ~Statistics() {}

  void    add_bytes(guint64 count);
  guint64 get_bytes() const;

  void    inc_sync_count();
  guint32 get_sync_count() const;

private:

  guint64 bytes_transferred_;
  guint32 sync_count_;

};

/* Inline implementation */

Statistics::Statistics()
  :
  bytes_transferred_(0),
  sync_count_(0)
{
}

inline void
Statistics::add_bytes(guint64 count)
{
  bytes_transferred_ += count;
}

inline guint64
Statistics::get_bytes() const
{
  return bytes_transferred_;
}

inline void
Statistics::inc_sync_count()
{
  sync_count_++;
}

inline guint32
Statistics::get_sync_count() const
{
  return sync_count_;
}

} // namespace Transfer

} // namespace USBSink

#endif // _TASK_STATS_H_
