/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 *  USBSink - utils.h
 *
 *  Copyright (C) 2006 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _UTILS_H_
#define _UTILS_H_

#include <list>
#include <string>

#include <glibmm/ustring.h>
#include <gtkmm/textbuffer.h>

namespace USBSink
{

namespace Util
{

class Point
{
public:
  Point() : x(0), y(0) {}
  Point(const Point& p) : x(p.x), y(p.y) {}
  Point(gint xx, gint yy) : x(xx), y(yy) {}

  gint x;
  gint y;
};

template<class T>
void free_t(T* t)
{
  delete t;
}

Glib::ustring i18n_printf(const Glib::ustring& a_format, ...);

namespace Config
{

/**
 * Application directory.
 */
std::string   get_rc_dir();
std::string   get_task_dir();
std::string   get_file_list_dir();

void          create_common_ignore_file_list();

Glib::ustring get_file_list_format_string();

} // namespace Config

namespace File
{

int                    count_files_in_dir(const std::string& path,
                                          bool recursive);

void                   make_missing_dirs_for_file(const Glib::ustring& path);

std::list<std::string> get_files_in_dir(const std::string& path);

Glib::ustring          peek_first_line(const std::string& path);

} // namespace File

namespace Regexp
{

bool validate(Glib::ustring& str);

} // namespace Regexp

namespace String
{

std::list<Glib::ustring> load_file_to_list(const Glib::ustring& filename);

std::list<Glib::ustring>
get_lines_from_text_buffer(const Glib::RefPtr<Gtk::TextBuffer>& buffer);

Glib::ustring trim_whitespace(const Glib::ustring& text);
int count_char(const Glib::ustring& text, gunichar c);
Glib::ustring delete_trailing_separator(const Glib::ustring& path);

Glib::ustring get_readable_byte_count(guint64 bytes);

} // namespace String

namespace Time
{

Glib::ustring get_current_time();
Glib::ustring get_modification_date_string(time_t timet);

} // namespace Time

} // namespace Util

} // namespace USBSink

#endif
